@@ -31,9 +31,6 @@ from ..utils.errors import (
 )
 
 
-DEFAULT_TRAIN_PARAMS = "[{\"name\":\"dataset\",\"type\":\"dataset\",\"suggest\":1}]"
-
-
 def sync_algorithm(
     id: Optional[str]=None,
     name: Optional[str]=None,
@@ -197,7 +194,6 @@ def _create_new_algorithm(name: str) -> Algorithm:
         visibility=ResourceVisibility.PRIVATE,
         filename=f"{name}.zip", # legacy
         is_zipfile=True, # legacy
-        train_params=DEFAULT_TRAIN_PARAMS,
         follows_anylearn_norm=False,
     )
     return algo
