@@ -204,7 +204,7 @@ class TestAlgorithm(BaseTestCase):
             algo.save()
         e = ctx.exception
         self.assertIsInstance(e, AnyLearnMissingParamException)
-        self.assertEqual(e.msg, "Algorithm缺少必要字段：['name', 'filename', 'mirror_id', 'train_params']")
+        self.assertEqual(e.msg, "Algorithm缺少必要字段：['name', 'filename', 'mirror_id']")
 
     # def test_create_algo_ko_empty_entrypoint_training_output_training(self):
     #     algo = Algorithm(name="TestALGO250", filename="test.tar.gz",
